# banking-api

## API and data-model for banking
### Supports
1. Creating customers
2. Creating customer accounts with initial balance
3. Transferring money between accounts
4. Getting a list of all accounts for a customer
5. Getting the balance for an account
6. Getting a list of transactions for an account